<?php
/**
 * @version     2.0.0
 * @package     Sellacious Filters Module
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Saurabh Sabhbarwal <info@bhartiy.com> - http://www.bhartiy.com
*/
namespace Sellacious\ProductsFilter;

use Joomla\CMS\Factory;
use Sellacious\Database\Table\Filter\FilterElement;

defined('_JEXEC') or die;

/**
 * Filter Class
 *
 * @package  Sellacious\ProductsFilter
 *
 * @since    2.0.0
 */
class Search extends AbstractFilter
{
	/**
	 * Method to compute and assign the values to be cached for the filter to work
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function buildCacheData()
	{

	}

	/**
	 * Method to populate the state with the filter values submitted
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function populateState()
	{

	}

	/**
	 * Method to apply the filter to search query using the state with values submitted
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function addFilter()
	{
		$search = $this->module->getState()->get('filter.search');
		$words  = array_filter(explode(' ', $search));

		if ($words)
		{
			$db    = Factory::getDbo();
			$query = $db->getQuery(true);
			$where = array();

			foreach ($words as $keyword)
			{
				$pattern = $db->q('%' . $db->escape($keyword, true) . '%', false);
				$format  = '(%2$s LIKE %1$s OR %3$s LIKE %1$s OR %4$s LIKE %1$s OR %5$s LIKE %1$s)';

				$where[] = sprintf($format, $pattern, 'title', 'local_sku', 'manufacturer_sku', 'tags');
			}

			$query->select('id')->from('#__sellacious_products')->where($where);

			$pks = (array) $db->setQuery($query)->loadColumn();
			$pks = array_map('intval', $pks);

			$this->module->getLoader()->addFilter(new FilterElement('in', 'product_id', $pks));
		}
	}

	/**
	 * Get required data for the filter form, if any
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	protected function getFilterFormData()
	{
		$value = $this->app->getUserState('com_sellacious.products.filter.search');

		return array('search' => $value);
	}

	/**
	 * Method to render the frontend filter form which can be submitted to apply a products filter
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function renderForm()
	{
		$view = $this->app->input->getCmd('view');

		if ($view === 'store' || $view === 'stores')
		{
			return;
		}

		parent::renderForm();
	}
}
