<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Sellacious\StoreTimings\StoreTimingsHelper;

JFormHelper::loadFieldClass('text');

/**
 * Form Field class for the Joomla Framework.
 *
 * @since   2.0.0
 */
class JFormFieldDeliveryDatePicker extends JFormFieldText
{
	/**
	 * The field type.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'DeliveryDatePicker';

	/**
	 * Method to get the field input markup.
	 *
	 * @return   string  The field input markup.
	 *
	 * @throws   Exception
	 *
	 * @since    2.0.0
	 */
	protected function getInput()
	{
		JHtml::_('jquery.framework');

		JHtml::_('script', 'com_sellacious/plugin/select2-3.5/select2.js', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('stylesheet', 'com_sellacious/plugin/select2-3.5/select2.css', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('stylesheet', 'plg_system_sellaciousdelivery/glyphicons.css', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('stylesheet', 'plg_system_sellaciousdelivery/bootstrap-datetimepicker.css', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('script', 'plg_system_sellaciousdelivery/moment-with-locales.js', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('script', 'plg_system_sellaciousdelivery/bootstrap-datetimepicker.js', array('version' => S_VERSION_CORE, 'relative' => true));

		$this->value   = is_object($this->value) ? (array) $this->value : $this->value;
		$id            = $this->id;
		$pickerId      = $id . '_dtpicker';
		$format        = 'YYYY-MM-DD';
		$sideBySide    = 'false';
		$timeSelection = (int)$this->element['time_selection'];
		$selectedDate  = $this->element['selected_date'] ? trim((string) $this->element['selected_date']) : '';
		$minDate       = !empty($selectedDate) ? "new Date('" . $selectedDate . "')" : "new Date()";
		$maxDate       = $this->element['max_date'] ? (string) $this->element['max_date'] : JFactory::getDate('Dec 31')->modify('+1 year')->toSql();
		$disabledDays  = $this->element['disabled_days'] ? implode(', ', array_map('trim', explode(',', $this->element['disabled_days']))) : '';
		$disabledDates = $this->element['disabled_dates'] ? implode('", "', json_decode($this->element['disabled_dates'])) : '';
		$code          = $this->element['product_uid'] ? (string) $this->element['product_uid'] : '';
		$sellerUid     = $this->element['seller_uid'] ? (int) $this->element['seller_uid'] : 0;
		$slotPickerId  = $this->element['slot_picker_id'] ? (string) $this->element['slot_picker_id'] : $id . '_slot_picker';
		$shipRuleId    = $this->element['shipping_rule_id'] ? (int) $this->element['shipping_rule_id'] : 0;
		$shipRates     = (string) $this->element['shipping_rates'] == 'false' ? false : true;
		$pickerType    = (string) $this->element['picker_type'] == '' ? 'delivery' : (string) $this->element['picker_type'];
		$defaultValue  = '';

		$disabledDays  = '[' . $disabledDays . ']';
		$disabledDates = '["' . $disabledDates . '"]';

		if ($timeSelection == 3)
		{
			$format     = 'YYYY-MM-DD HH:mm A';
			$sideBySide = 'true';
		}

		$dateValue = null;

		if (is_array($this->value))
		{
			$this->value['date'] = str_replace(array('AM', 'PM'), '', $this->value['date']);

			if (isset($this->value['date']))
			{
				$defaultValue = "date: new Date('" . $this->value['date'] . "')";
				$dateValue    = $this->value['date'];
			}
		}
		else
		{
			$this->value = str_replace(array('AM', 'PM'), '', $this->value);

			if ($this->value)
			{
				$defaultValue = "date: new Date('" . $this->value . "')";
				$dateValue    = $this->value;
			}
		}

		$nextHourSlabs = array();

		if ($shipRuleId && $shipRates)
		{
			$nextHourSlabs = $this->getNextTimeSlabs($shipRuleId, $sellerUid);
		}

		$days = array_keys(SellaciousHelperSeller::DAYS);

		$params = array(
			'id'              => $id,
			'pickerId'        => $pickerId,
			'pickerType'      => $pickerType,
			'slotPickerId'    => $slotPickerId,
			'format'          => $format,
			'minDate'         => trim((string) $this->element['selected_date']),
			'maxDate'         => $maxDate,
			'disabledDates'   => $disabledDates,
			'disabledDays'    => $disabledDays,
			'allDaysDisabled' => (bool) (json_decode($disabledDays) === $days),
			'sideBySide'      => (bool) $sideBySide,
			'value'           => $dateValue,
			'sellerUid'       => $sellerUid,
			'code'            => $code,
			'shipRuleId'      => $shipRuleId,
			'shipRates'       => $shipRates,
			'nextHourSlabs'   => $nextHourSlabs,
			'timeSelection'   => $timeSelection,
		);

		$data = array(
			'name'     => $this->name,
			'id'       => $id,
			'pickerId' => $pickerId,
			'value'    => $this->value,
			'params'   => $params
		);
		$html = $this->renderPicker($data);

		JText::script('PLG_SYSTEM_SELLACIOUSDELIVERY_CALENDAR');

		$doc = JFactory::getDocument();
		$js  = <<<JS
		jQuery(document).ready(function($) {
			$('#{$pickerId}').datetimepicker({
				format: '{$format}',
				minDate: {$minDate},
				maxDate: new Date('{$maxDate}'),
				disabledDates: {$disabledDates},
				daysOfWeekDisabled: {$disabledDays},
				sideBySide: {$sideBySide},
				showClose: true,
			    toolbarPlacement: 'top',
			    {$defaultValue}
			}).on('dp.change', function (e) {
			    let newDate = null, oldDate = null;
			    
			    if (e.oldDate !== undefined) {
			        newDate = e.date.format('YYYY-MM-DD');
			        oldDate = e.oldDate.format('YYYY-MM-DD');
			    }
			    
			    var date = $('#{$id}').val();
			
				var data = {
					option: 'com_ajax',
					plugin: 'sellaciousdelivery',
					method: 'onAjaxGetSlots',
					slot_date: date,
					code: '{$code}',
					seller_uid: '{$sellerUid}',
					format: 'json'
				};
				
				var paths = Joomla.getOptions('system.paths', {});
				var base  = paths.root || '';
				
				$.ajax({
					url: base + '/index.php',
					type: 'POST',
					dataType: 'json',
					cache: false,
					data: data,
				}).done(function (response) {
				    if (response.success == true) {
				        if (response.data.disabled_intervals.length && (!oldDate || (newDate !== oldDate))) {
				            var disabledIntervals = [];
				            
				            $.each(response.data.disabled_intervals, function(key, interval){
				                var disabledInterval = [];
				                
				                disabledInterval.push(moment(interval.min));
				                disabledInterval.push(moment(interval.max));
				                
				                disabledIntervals.push(disabledInterval);
				            });
				            
				            $('#{$pickerId}').data('DateTimePicker').disabledTimeIntervals(disabledIntervals);
				        }
				        
						if (response.data.html != "") {
							$('#{$slotPickerId}').html(response.data.html);
							$('#{$slotPickerId}').select2();
						}
						
						if ($('.btn-date[data-delivery-date="' + date + '"').length) {
							$('#{$pickerId} .input-group-addon').html(Joomla.JText._('PLG_SYSTEM_SELLACIOUSDELIVERY_CALENDAR'));
						} else {
							var dt = response.data.date;
							$('#{$pickerId} .input-group-addon').html(dt.weekday + '<br>' + dt.day).addClass('active');
						}
					} else {
						Joomla.renderMessages({warning: [response.message]});
					}
				}).fail(function (jqXHR) {
					Joomla.renderMessages({warning: ['Request failed due to unknown error.']});
				});
			});
			
			$('#{$pickerId}').trigger('dp.change');
		});
JS;
		$doc->addScriptDeclaration($js);

		return $html;
	}

	/**
	 * Render field
	 *
	 * @param   array $data The data
	 *
	 * @return  string
	 *
	 * @since   2.0.0
	 *
	 * @throws  Exception
	 */
	protected function renderPicker($data)
	{
		ob_start();
		$layoutPath = JPluginHelper::getLayoutPath('system', 'sellaciousdelivery', 'field_deliverydatepicker');

		if (is_file($layoutPath))
		{
			$displayData = $data;

			unset($namespace, $layout);

			/**
			 * Variables available to the layout
			 *
			 * @var  $this
			 * @var  $layoutPath
			 * @var  $displayData
			 */
			include $layoutPath;
		}

		return ob_get_clean();
	}

	/**
	 * Method to get next time slabs
	 *
	 * @param   int  $shipRuleId  Shipping rule id
	 * @param   int  $sellerUid   Seller user id
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	protected function getNextTimeSlabs($shipRuleId, $sellerUid)
	{
		$helper        = SellaciousHelper::getInstance();
		$nextHourSlabs = array();

		$todayAvailability = null;
		$sellerTimeZone    = null;
		$now               = JFactory::getDate();

		if ($sellerUid)
		{
			$seller = $helper->seller->getItem(array('user_id' => $sellerUid));
			$params = new Registry($seller->params);

			$sellerTimeZone    = StoreTimingsHelper::getUserTimezone($sellerUid);
			$now               = JFactory::getDate('now', $sellerTimeZone);
			$todayAvailability = $params->get('today_availability', '');
			$todayAvailability = $todayAvailability ? JFactory::getDate($now->format('Y-m-d', true) . ' ' . $todayAvailability, $sellerTimeZone) : null;
		}

		if ($nextHourRates = StoreTimingsHelper::getNextTimeRates($shipRuleId))
		{
			foreach ($nextHourRates as $nextHourRate)
			{
				if ($nextHourRate->add_to_slot_rates)
				{
					continue;
				}

				$xTime  = $nextHourRate->next_x_time;
				$xUnit  = $xTime['u'];
				$xValue = $xTime['m'];
				$time   = $xValue . ' ' . $xUnit;
				$slotDt = JFactory::getDate('now', $sellerTimeZone);

				$sellerTiming = null;

				if ($xUnit == 'tomorrow')
				{
					$slotDt->modify('+1 day');

					$weekDay      = $helper->core->getWeekDay($slotDt);
					$sellerTiming = $helper->seller->getTiming($sellerUid, $weekDay, 'delivery_hours');

					if (!$sellerTiming)
					{
						continue;
					}

					$slotDt = JFactory::getDate($slotDt->format('Y-m-d') . ' ' . $sellerTiming->to_time, $sellerTimeZone);
				}
				elseif ($xUnit == 'today')
				{
					$weekDay      = $helper->core->getWeekDay($slotDt);
					$sellerTiming = $helper->seller->getTiming($sellerUid, $weekDay, 'delivery_hours');

					if (!$sellerTiming)
					{
						continue;
					}

					$slotDt = JFactory::getDate($now->format('Y-m-d') . ' ' . $sellerTiming->to_time, $sellerTimeZone);
				}
				else
				{
					$slotDt->modify('+ '. $time);

					$weekDay      = $helper->core->getWeekDay($slotDt);
					$sellerTiming = $helper->seller->getTiming($sellerUid, $weekDay, 'delivery_hours');

					if (!$sellerTiming)
					{
						continue;
					}

					if ($xUnit == 'days')
					{
						$slotDt = JFactory::getDate($slotDt->format('Y-m-d') . ' ' . $sellerTiming->to_time, $sellerTimeZone);
					}
				}

				if ($sellerTiming && $xUnit != 'tomorrow')
				{
					$slotDay  = $slotDt->format('Y-m-d');
					$fromTime = JFactory::getDate($slotDay . ' ' . $sellerTiming->from_time, $sellerTimeZone);
					$toTime   = JFactory::getDate($slotDay . ' ' . $sellerTiming->to_time, $sellerTimeZone);

					if ($slotDay == $now->format('Y-m-d') && ($slotDt < $fromTime || $slotDt > $toTime))
					{
						continue;
					}
				}

				if ($todayAvailability && $slotDt->format('Y-m-d') == $now->format('Y-m-d') && $todayAvailability < $now)
				{
					continue;
				}

				$slab           = array();
				$slab['time']   = $nextHourRate->formatted_time;
				$slab['amount'] = $nextHourRate->amount;
				$slab['date']   = $slotDt->toSql(true);
				$slab['id']     = 'slab_' . $shipRuleId . '_' . str_replace(' ', '_', $time);

				$nextHourSlabs[$time] = $slab;
			}
		}

		return $nextHourSlabs;
	}
}
