<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

use Sellacious\StoreTimings\StoreTimingsHelper;

JFormHelper::loadFieldClass('List');

/**
 * Form Field class for the Joomla Framework.
 *
 * @since   2.0.0
 */
class JFormFieldSlotPicker extends JFormFieldList
{
	/**
	 * The field type.
	 *
	 * @var  string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'SlotPicker';

	/**
	 * Method to get the field input markup for a generic list.
	 * Use the multiple attribute to enable multiselect.
	 *
	 * @return  string  The field input markup.
	 *
	 * @since   2.0.0
	 */
	protected function getInput()
	{
		$html = parent::getInput();

		$sellerUid = $this->element['seller_uid'] ? (int) $this->element['seller_uid'] : 0;
		$itemUid   = $this->element['item_uid'] ? (string) $this->element['item_uid'] : '';

		$html .= '<input type="hidden" class="delivery-slot-data" 
			data-seller-uid="' . $sellerUid . '"  data-item-uid="' . $itemUid . '" id="' . $this->id . '_data" />';

		return $html;
	}

	/**
	 * Method to get the field options.
	 *
	 * @return  array  The field option objects.
	 *
	 * @since   2.0.0
	 */
	protected function getOptions()
	{
		$options = parent::getOptions();

		$sellerUid  = $this->element['seller_uid'] ? (int) $this->element['seller_uid'] : 0;
		$shipRuleId = $this->element['shipping_rule_id'] ? (int) $this->element['shipping_rule_id'] : 0;
		$slotDate   = $this->element['slot_date'] ? (string) $this->element['slot_date'] : '';
		$pickerType = (string) $this->element['picker_type'] == '' ? 'delivery' : (string) $this->element['picker_type'];

		if ($sellerUid && $slotDate)
		{
			$slotOptions = StoreTimingsHelper::getAvailableSlots(0, $sellerUid, $slotDate, '', false, $pickerType, $shipRuleId);

			if ($slotOptions)
			{
				foreach ($slotOptions as $value => $text)
				{
					$options[] = JHtml::_('select.option', $value, $text);
				}
			}
		}

		return $options;
	}
}
