<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

/**
 * Form Field class
 *
 * @since   2.0.0
 */
class JFormFieldSlotRates extends JFormField
{
	/**
	 * The field type.
	 *
	 * @var   string
	 *
	 * @since   2.0.0
	 */
	protected $type = 'SlotRates';

	/**
	 * Method to get the field input markup.
	 *
	 * @return   string  The field input markup.
	 *
	 * @throws   Exception
	 *
	 * @since    2.0.0
	 */
	protected function getInput()
	{
		$helper     = SellaciousHelper::getInstance();
		$required   = $this->required ? 'required ' : '';
		$disabled   = $this->disabled ? 'disabled ' : '';
		$readonly   = $this->readonly ? 'readonly ' : '';
		$value      = is_string($this->value) ? json_decode($this->value, true) : (array) $this->value;
		$flatRate   = isset($value['flat_rate']) ? $value['flat_rate'] : 0.00;
		$checked    = isset($value['variable_rates']) && $value['variable_rates'] == 1;
		$sellerUid  = $this->element['seller_uid'] ? (int) $this->element['seller_uid'] : 0;
		$shipRuleId = $this->element['shipping_rule_id'] ? (int) $this->element['shipping_rule_id'] : 0;

		$currency      = $helper->currency->getGlobal();
		$currencyClass = 'g-currency';

		$text1         = JText::_('PLG_SYSTEM_SELLACIOUSDELIVERY_FIELD_SLOTRATES_FLAT_RATE');
		$text2         = JText::_('PLG_SYSTEM_SELLACIOUSDELIVERY_FIELD_SLOTRATES_FLAT_RATE_DESC');
		$checkboxLabel = JText::_('PLG_SYSTEM_SELLACIOUSDELIVERY_FIELD_SLOTRATES_VARIABLE_RATES');
		$editLabel     = JText::_('PLG_SYSTEM_SELLACIOUSDELIVERY_FIELD_SLOTRATES_EDIT_RATES');
		$checkedAttr   = $checked ? 'checked' : '';
		$editClass     = $checked ?: 'hidden';
		$readonly      = $checked ? 'readonly' : $readonly;
		$link          = htmlspecialchars('index.php?option=com_sellaciousdelivery&view=slots&seller_uid=' . $sellerUid . '&shipping_rule_id=' . $shipRuleId);

		JHtml::_('jquery.framework');
		JHtml::_('script', 'com_sellacious/plugin/jquery.iframe-drawer.js', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('script', 'com_sellacious/util.float-val.js', array('version' => S_VERSION_CORE, 'relative' => true));
		JHtml::_('script', 'plg_system_sellaciousdelivery/field.slotrates.js', array('version' => S_VERSION_CORE, 'relative' => true));

		$html = <<<HTML
			<div class="field-slot-rates" id="{$this->id}">
				<div class="input-group" style="display: block;">
					<label class="pull-left" style="margin: 5px;">{$text1}</label>
					<input type="text" name="{$this->name}[flat_rate]" value="{$flatRate}" id="{$this->id}_flat_rate"
					    class="form-control w100px pull-lef flat_rate {$required} {$this->class}" {$disabled} {$readonly}
					    data-float="{$currency->decimal_places}" />
					    <label class="btn btn-default pull-left disabled"><span class="{$currencyClass}">{$currency->code_3}</span></label>
				    <label class="pull-left" style="margin: 5px;">{$text2}</label>
				</div>
				<div class="clearfix"></div> 
				<div class="margin-top-10 edit-rates-block">
					<label for="{$this->id}_variable_rates" class="checkbox pull-left">
						<input type="checkbox" name="{$this->name}[variable_rates]" 
						class="variable_rates"
						id="{$this->id}_variable_rates" value="1" {$checkedAttr}/>
						<span>{$checkboxLabel}</span>
					</label>
					<button type="button" class="btn btn-primary edit-rates {$editClass}" data-drawer-url="{$link}">
						{$editLabel}
					</button>
				</div> 
			</div>
HTML;

		return $html;
	}
}
