/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

(function ($) {
    $(document).ready(function () {
        $(document).on('onLoadShippingForms', function(selector, container){
            $.each($(container).find('.delivery_date'), function () {
                let $this = $(this);
                let params = $this.data('params');
                let selDate = params.value ? new Date(params.value) : null;
                let pickerVal = $('#' + params.slotPickerId).val();

                if ($('#' + params.id + '_pick_date .slabpicker.active').length) {
                    selDate = null;
                }

                $('#' + params.pickerId).datetimepicker({
                    format: params.format,
                    minDate: params.minDate ? new Date(params.minDate) : new Date(),
                    maxDate: new Date(params.maxDate),
                    disabledDates: JSON.parse(params.disabledDates),
                    daysOfWeekDisabled: JSON.parse(params.disabledDays),
                    sideBySide: params.sideBySide,
                    showClose: true,
                    toolbarPlacement: 'top',
                    date: selDate
                }).on('dp.change', function (e) {
                    $this.closest('.slot_section').find('.datepicker .input-group-addon').removeClass('active');

                    var date = $('#' + params.id).val();

                    var data = {
                        option: 'com_ajax',
                        plugin: 'sellaciousdelivery',
                        method: 'onAjaxGetSlots',
                        slot_date: date,
                        code: params.code,
                        seller_uid: params.sellerUid,
                        shipping_rule_id: params.shipRuleId ? params.shipRuleId : 0,
                        slot_type: params.pickerType ? params.pickerType : 'delivery',
                        ship_rates: params.shipRates,
                        format: 'json'
                    };

                    var paths = Joomla.getOptions('system.paths', {});
                    var base  = paths.root || '';

                    $.ajax({
                        url: base + '/index.php',
                        type: 'POST',
                        dataType: 'json',
                        cache: false,
                        data: data,
                    }).done(function (response) {
                        if (response.success == true) {
                            $('#' + params.slotPickerId).html(response.data.html);
                            $('#' + params.slotPickerId).attr('required', true);
                            $('#' + params.slotPickerId).select2();

                            $('#' + params.slotPickerId).closest('.ctech-form-group').removeClass('hidden');
                            $this.closest('.slot_section').find('.delivery_date_amount').val('');
                            $this.closest('.slot_section').find('.delivery_date_id').val('');

                            if ($('.btn-date[data-delivery-date="' + date + '"').length) {
                                $('#' + params.pickerId + '.input-group-addon').html(Joomla.JText._('PLG_SYSTEM_SELLACIOUSDELIVERY_CALENDAR'));
                            } else {
                                var dt = response.data.date;
                                $('#' + params.pickerId + ' .input-group-addon').html(dt.weekday + '<br>' + dt.day).addClass('active');
                            }
                        } else {
                            Joomla.renderMessages({warning: [response.message]});
                        }
                    }).fail(function (jqXHR) {
                        Joomla.renderMessages({warning: ['Request failed due to unknown error.']});
                    });
                });

                if (selDate && !pickerVal) {
                    $('#' + params.pickerId).triggerHandler('dp.change');
                }

                var setupSlabPicker = function (slab_picker) {
                    if (!slab_picker.length) {
                        return;
                    }

                    let parent = slab_picker.closest('.slot_section');

                    let amount = slab_picker.data('amount');
                    let date = slab_picker.data('date');
                    let id = slab_picker.data('id');

                    parent.find('.datepicker .input-group-addon').removeClass('active');
                    parent.find('.delivery_date_id').val(id);
                    parent.find('.delivery_date_amount').val(amount);
                    parent.find('.delivery_date').val(date);

                    slab_picker.addClass('active');

                    $('#' + params.slotPickerId).attr('required', false);
                    $('#' + params.slotPickerId).closest('.ctech-form-group').addClass('hidden');
                }

                $('#' + params.id + '_pick_date .slabpicker').on('click', function () {
                    let $this = $(this);
                    setupSlabPicker($this);

                    var sellerUid = $('#' + params.slotPickerId + '_data').data('seller-uid');
                    var itemUid = $('#' + params.slotPickerId + '_data').data('item-uid');

                    $('.select-seller-shipment[data-seller-uid="' + sellerUid + '"][data-item-uid="' + itemUid + '"]').trigger('change');
                });

                setupSlabPicker($('#' + params.id + '_pick_date .slabpicker.active'));

                $('#' + params.slotPickerId).on('change', function () {

                    var sellerUid = $('#' + params.slotPickerId + '_data').data('seller-uid');
                    var itemUid = $('#' + params.slotPickerId + '_data').data('item-uid');

                    $('.select-seller-shipment[data-seller-uid="' + sellerUid + '"][data-item-uid="' + itemUid + '"]').trigger('change');
                });

                if ($('#' + params.pickerId).length) {
                    let date = $('#' + params.pickerId).data('DateTimePicker').date();

                    if (date) {
                        $('#' + params.pickerId + ' .input-group-addon')
                            .html(date.format('ddd') + '<br>' + date.format('MMMM') + ' ' + date.format('DD'))
                            .addClass('active');
                    }
                }
            });
        });
    });
})(jQuery);
