<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

namespace Sellacious\Buttons;

// no direct access.
defined('_JEXEC') or die;

class CheckoutButton
{
	/**
	 * Name of the checkout button
	 *
	 * @var  string
	 *
	 * @since  2.0.0
	 */
	protected $name;

	/**
	 * Text for the button
	 *
	 * @var  string
	 *
	 * @since  2.0.0
	 */
	protected $text;

	/**
	 * Classes to be added on the html button
	 *
	 * @var  array
	 *
	 * @since  2.0.0
	 */
	protected $classes;

	/**
	 * Additional html attributes for the button
	 *
	 * @var  array
	 *
	 * @since  2.0.0
	 */
	protected $attributes;

	/**
	 * CheckoutButton constructor.
	 *
	 * @param   string  $name
	 * @param   string  $text
	 *
	 * @since   2.0.0
	 */
	public function __construct($name, $text)
	{
		$this->set('name', $name);
		$this->set('text', $text);
	}

	/**
	 * Method to set a property
	 *
	 * @param   string  $property
	 * @param   mixed   $value
	 *
	 * @since   2.0.0
	 */
	public function set($property, $value)
	{
		if (property_exists($this, $property))
		{
			$this->$property = $value;
		}
	}

	/**
	 * Method to set a property
	 *
	 * @param   string  $property
	 *
	 * @return  mixed
	 *
	 * @since   2.0.0
	 */
	public function get($property)
	{
		return property_exists($this, $property) ? $this->$property : null;
	}

	/**
	 * Method to add a class
	 *
	 * @param   string  $class
	 *
	 * @since   2.0.0
	 */
	public function addClass($class)
	{
		$this->classes[] = $class;
	}

	/**
	 * Method to add an html attribute for button
	 *
	 * @param   string  $key
	 * @param   string  $value
	 *
	 * @since   2.0.0
	 */
	public function addAttribute($key, $value)
	{
		$this->attributes[$key] = $value;
	}

	/**
	 * Method to get the whole object as array
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	public function toArray()
	{
		return array(
			'name'       => $this->get('name'),
			'text'       => $this->get('text'),
			'classes'    => $this->get('classes'),
			'attributes' => $this->get('attributes'),
		);
	}
}
