<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

namespace Sellacious\Buttons;

// no direct access.
defined('_JEXEC') or die;

use Exception;
use Joomla\Registry\Registry;
use JText;
use Sellacious\Event\EventHelper;

class CheckoutButtonsHelper
{
	/**
	 * Method to get additional checkout buttons
	 *
	 * @param   Registry  $item     Product item object
	 * @param   string    $context  Context
	 *
	 * @return  array
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getAdditionalCheckoutButtons(Registry $item, $context = 'com_sellacious.product')
	{
		$buttons         = array();
		$checkoutButtons = array();

		$arguments = array(
			'context' => $context,
			'item'    => $item,
			'buttons' => &$buttons,
		);

		$event   = EventHelper::trigger('onRenderCheckoutButtons', $arguments);
		$buttons = $event->getArgument('buttons');

	    if ($buttons)
	    {
		    foreach ($buttons as $key => $button)
		    {
			    if (!$button instanceof CheckoutButton)
			    {
			    	throw new Exception(JText::_('COM_SELLACIOUS_CHECKOUT_BUTTONS_EXCEPTION_INVALID_BUTTON'));
			    }

			    $checkoutButtons[$key] = $button->toArray();
	    	}
	    }

		return $checkoutButtons;
	}
}
