<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Joomla\Utilities\ArrayHelper;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;
use stdClass;

class CategoryAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		return array(
			'category'        => 'string',
			'category_ext'    => 'string',
			'category_id'     => 'string',
			'category_id_ext' => 'string',
		);
	}

	/**
	 * Get the cache record properties
	 *
	 * @param   int  $productId
	 *
	 * @return  stdClass
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function getRecord($productId)
	{
		$obj = new stdClass;

		$categories = $this->getCategories($productId);

		$obj->category        = $categories;
		$obj->category_ext    = $this->getCategoriesParents(array_keys($categories));
		$obj->category_id     = array_map('intval', array_keys($obj->category));
		$obj->category_id_ext = array_map('intval', array_keys($obj->category_ext));

		return $obj;
	}

	protected function getCategories($productId)
	{
		$filter  = array(
			'list.select' => 'a.id, a.title',
			'list.join'   => array(
				array('inner', $this->db->quoteName('#__sellacious_product_categories', 'pc') . ' ON a.id = pc.category_id'),
			),
			'state'       => 1,
			'list.where'  => 'pc.product_id = ' . (int) $productId,
		);
		$records = $this->helper->category->loadObjectList($filter) ?: array();
		$records = ArrayHelper::getColumn($records, 'title', 'id');

		return $records;
	}

	protected function getCategoriesParents(array $pks)
	{
		$records = array();

		if ($pks)
		{
			$aks = $this->helper->category->getParents($pks, true, array('state' => 1));
			$aks = $this->helper->category->loadObjectList(array('list.select' => 'a.id, a.title', 'id' => $aks));

			$records = ArrayHelper::getColumn($aks, 'title', 'id');
		}

		return $records;
	}
}
