<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;
use stdClass;

class PhysicalAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		// Type casting would not be necessary as these columns will
		// not be used for filtering records
		return array(
			'length'     => 'string',
			'width'      => 'string',
			'height'     => 'string',
			'weight'     => 'string',
			'vol_weight' => 'string',
		);
	}

	public function getRecord($productId)
	{
		$obj   = new stdClass;
		$query = $this->getQuery();

		$query->where('product_id = ' . (int) $productId);

		$props = $this->db->setQuery($query)->loadAssoc() ?: array();

		foreach ($props as $key => $value)
		{
			$obj->$key = @json_decode($value) ?: null;
		}

		return $obj;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$query = $this->db->getQuery(true);

			$query->select('length, width, height, weight, vol_weight')->from($this->db->quoteName('#__sellacious_product_physical'));
		}

		return clone $query;
	}
}
