<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;

class PsxElectronicAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		// No typecasting required as not used in filtering
		static $columns = array(
			'delivery_mode'   => 'string',
			'download_limit'  => 'int',
			'download_period' => 'string',
			'preview_mode'    => 'string',
			'preview_url'     => 'string',
		);

		return $columns;
	}

	public function getRecord($psxId)
	{
		$query = $this->getQuery();

		$query->where('psx_id = ' . (int) $psxId);

		$obj = $this->db->setQuery($query)->loadObject();

		if ($obj)
		{
			$obj->download_period = json_decode($obj->download_period);
		}

		return $obj;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$query = $this->db->getQuery(true);

			$query->select('delivery_mode, download_limit, download_period, preview_mode, preview_url');
			$query->from($this->db->quoteName('#__sellacious_eproduct_sellers'));
		}

		return clone $query;
	}
}
