<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;
use stdClass;

class PsxPhysicalAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		return array(
			'listing_type'      => 'int',
			'item_condition'    => 'int',
			'flat_shipping'     => 'int',
			'shipping_flat_fee' => 'float',
			'return_days'       => 'int',
			'return_tnc'        => 'string',
			'exchange_days'     => 'int',
			'exchange_tnc'      => 'string',
			'whats_in_box'      => 'string',
			'shipping_length'   => 'string',
			'shipping_width'    => 'string',
			'shipping_height'   => 'string',
			'shipping_weight'   => 'string',
		);
	}

	public function getRecord($psxId)
	{
		$query = $this->getQuery();

		$query->where('psx_id = ' . (int) $psxId);

		$obj = $this->db->setQuery($query)->loadObject();

		if ($obj)
		{
			// These columns do not require type casting as they don't allow filtering
			$obj->shipping_length = @json_decode($obj->shipping_length) ?: null;
			$obj->shipping_width  = @json_decode($obj->shipping_width) ?: null;
			$obj->shipping_height = @json_decode($obj->shipping_height) ?: null;
			$obj->shipping_weight = @json_decode($obj->shipping_weight) ?: null;

			static::fixType($obj);
		}

		return $obj;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$query = $this->db->getQuery(true);

			$query->select('listing_type, item_condition, flat_shipping, shipping_flat_fee, return_days, return_tnc, exchange_days, exchange_tnc, whats_in_box');
			$query->select('length as shipping_length, width as shipping_width, height as shipping_height, weight as shipping_weight');
			$query->from($this->db->quoteName('#__sellacious_physical_sellers'));
		}

		return clone $query;
	}

	/**
	 * Convert the data type of the columns which are not explicitly definitive
	 *
	 * @param   stdClass  $obj
	 *
	 * @return  stdClass
	 *
	 * @since   2.0.0
	 */
	protected static function fixType($obj)
	{
		$obj->listing_type      = (int) $obj->listing_type;
		$obj->item_condition    = (int) $obj->item_condition;
		$obj->flat_shipping     = (int) $obj->flat_shipping;
		$obj->shipping_flat_fee = (float) $obj->shipping_flat_fee;
		$obj->return_days       = (int) $obj->return_days;
		$obj->exchange_days     = (int) $obj->exchange_days;

		return $obj;
	}
}
