<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Joomla\CMS\Factory;
use Joomla\Utilities\ArrayHelper;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;
use stdClass;

class SplCategoryAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		return array(
			'spl_category' => 'string',
			'spl_cat_ids'  => 'string',
		);
	}

	public function getRecord($productId, $sellerUid = null)
	{
		$query = $this->getQuery();

		$query->where('l.product_id = ' . (int) $productId);
		$query->where('l.seller_uid = ' . (int) $sellerUid);

		$records = $this->db->setQuery($query)->loadObjectList();
		$values  = ArrayHelper::getColumn($records, 'title', 'id');

		$obj = new stdClass;

		$obj->spl_category = $values;
		$obj->spl_cat_ids  = array_map('intval', array_keys($values));

		return $obj;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$now  = Factory::getDate()->toSql();
			$nDt  = $this->db->getNullDate();
			$cond = array(
				'l.publish_up != ' . $this->db->q($nDt),
				'l.publish_down != ' . $this->db->q($nDt),
				'l.publish_up <= ' . $this->db->q($now),
				'l.publish_down > ' . $this->db->q($now),
				'l.category_id = c.id',
				'l.category_id > 0',
				'l.state = 1',
			);

			$query = $this->db->getQuery(true);

			$query->select('c.id, c.title')
				->from($this->db->quoteName('#__sellacious_splcategories', 'c'))
				->order('c.lft');

			$query->join('inner', $this->db->quoteName('#__sellacious_seller_listing', 'l') . ' ON ' . implode(' AND ', $cond));
		}

		return clone $query;
	}
}
