<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;

class VariantAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		static $columns = array(
			'variant_id'          => 'int',
			'variant_title'       => 'string',
			'variant_alias'       => 'string',
			'variant_sku'         => 'string',
			'variant_description' => 'string',
			'variant_features'    => 'string',
			'variant_active'      => 'int',
		);

		return $columns;
	}

	public function getRecord($productId)
	{
		$variants = array();

		if ($this->config->get('multi_variant'))
		{
			$query = $this->getQuery();
			$query->where('v.product_id = ' . (int) $productId);

			$variants = (array) $this->db->setQuery($query)->loadObjectList('variant_id');

			foreach ($variants as $variant)
			{
				$variant->variant_features = json_decode($variant->variant_features);
			}
		}

		return $variants;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$columns = array(
				'variant_id'          => 'v.id',
				'variant_title'       => 'v.title',
				'variant_alias'       => 'v.alias',
				'variant_sku'         => 'v.local_sku',
				'variant_description' => 'v.description',
				'variant_features'    => 'v.features',
				'variant_active'      => 'v.state',
			);

			$query = $this->db->getQuery(true);

			$query->select($this->db->quoteName(array_values($columns), array_keys($columns)))
				->from($this->db->quoteName('#__sellacious_variants', 'v'));
		}

		return clone $query;
	}
}
