<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Builder\Adapter\Product;

use Exception;
use Sellacious\Cache\Builder\Adapter\AbstractCacheAdapter;
use stdClass;

class VsxAdapter extends AbstractCacheAdapter
{
	/**
	 * Get the list of cache columns
	 *
	 * @return  string[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function getColumns()
	{
		static $columns = array(
			'vsx_id'                 => 'int',
			'variant_price_mod'      => 'float',
			'variant_price_mod_perc' => 'int',
			'stock'                  => 'int',
			'over_stock'             => 'int',
			'stock_reserved'         => 'int',
			'stock_sold'             => 'int',
			'stock_capacity'         => 'int',
			'no_stock'               => 'int',
			'is_selling_variant'     => 'int',
		);

		return $columns;
	}

	public function getRecord($variantId, $sellerUid = 0)
	{
		$query = $this->getQuery();

		$query->where('a.variant_id = ' . (int) $variantId)
			->where('a.seller_uid = ' . (int) $sellerUid);

		$obj = $this->db->setQuery($query)->loadObject();

		if ($obj)
		{
			static::fixType($obj);
		}

		return $obj;
	}

	protected function getQuery()
	{
		static $query;

		if (!$query)
		{
			$query = $this->db->getQuery(true);
			$cols  = array(
				'vsx_id'                 => 'a.id',
				'variant_price_mod'      => 'a.price_mod',
				'variant_price_mod_perc' => 'a.price_mod_perc',
				'stock'                  => 'a.stock',
				'over_stock'             => 'a.over_stock',
				'stock_reserved'         => 'a.stock_reserved',
				'stock_sold'             => 'a.stock_sold',
				'is_selling_variant'     => 'a.state',
			);

			$query->select($this->db->quoteName(array_values($cols), array_keys($cols)));
			$query->select('a.stock + a.over_stock AS stock_capacity');
			$query->select('a.stock + a.over_stock <= 0 AS no_stock');
			$query->from($this->db->quoteName('#__sellacious_variant_sellers', 'a'));
		}

		return clone $query;
	}

	/**
	 * Convert the data type of the columns which are not explicitly definitive
	 *
	 * @param   stdClass  $obj
	 *
	 * @return  stdClass
	 *
	 * @since   2.0.0
	 */
	protected static function fixType($obj)
	{
		$obj->vsx_id                 = (int) $obj->vsx_id;
		$obj->variant_price_mod      = (float) $obj->variant_price_mod;
		$obj->variant_price_mod_perc = (int) $obj->variant_price_mod_perc;
		$obj->stock                  = (int) $obj->stock;
		$obj->over_stock             = (int) $obj->over_stock;
		$obj->stock_reserved         = (int) $obj->stock_reserved;
		$obj->stock_sold             = (int) $obj->stock_sold;
		$obj->stock_capacity         = (int) $obj->stock_capacity;
		$obj->no_stock               = (int) $obj->no_stock;
		$obj->is_selling_variant     = (int) $obj->is_selling_variant;

		return $obj;
	}
}
