<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Cache\Storage;

use Exception;
use JDatabaseIterator;
use Sellacious\Cache\Reader\AbstractCacheReader;
use stdClass;

defined('_JEXEC') or die;

/**
 * Class AbstractCacheStorageRead
 *
 * @package  Sellacious\Cache
 *
 * @since   2.0.0
 */
abstract class AbstractCacheStorageRead
{
	/**
	 * @var   AbstractCacheReader
	 *
	 * @since   2.0.0
	 */
	protected $reader;

	/**
	 * AbstractCacheStorage constructor
	 *
	 * @param   AbstractCacheReader  $reader
	 *
	 * @since   2.0.0
	 */
	public function __construct(AbstractCacheReader $reader)
	{
		$this->setReader($reader);
	}

	/**
	 * Set the reader instance
	 *
	 * @param   AbstractCacheReader  $reader
	 *
	 * @since   2.0.0
	 */
	public function setReader(AbstractCacheReader $reader)
	{
		$this->reader = $reader;
	}

	/**
	 * Method to check the schema version for the application compatibility
	 *
	 * @param   int  $version
	 *
	 * @return  bool
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	abstract public function matchVersion($version);

	/**
	 * Method to load a single record found with matching filters
	 *
	 * @return  stdClass
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	abstract public function getItem();

	/**
	 * Method to load a list of records found with matching filters
	 *
	 * @param   int  $offset  The called method
	 * @param   int  $limit   The array of arguments passed to the method
	 *
	 * @return  stdClass[]
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	abstract public function getItems($offset = 0, $limit = 0);

	/**
	 * Method to load an iterator for records found with matching filters
	 *
	 * @return  JDatabaseIterator
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	abstract public function getIterator();

	/**
	 * Method to find number of matching records
	 *
	 * @return  int
	 *
	 * @since   2.0.0
	 */
	abstract public function getTotal();
}
