<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\Database\Table\Sort;

use JsonSerializable;

defined('_JEXEC') or die;

class TableSort implements JsonSerializable
{
	protected $col;

	protected $dir;

	const SORT_ASC = 1;

	const SORT_DESC = -1;

	/**
	 * Filter constructor
	 *
	 * @param  string  $col
	 * @param  int     $dir
	 *
	 * @since   2.0.0
	 */
	public function __construct($col, $dir = self::SORT_ASC)
	{
		$this->col = $col;
		$this->dir = $dir;
	}

	/**
	 * Return data which should be serialized by json_encode()
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	public function jsonSerialize()
	{
		return get_object_vars($this);
	}

	/**
	 * Get sort column name
	 *
	 * @return  string
	 *
	 * @since   2.0.0
	 */
	public function getCol()
	{
		return $this->col;
	}

	/**
	 * Get sort direction
	 *
	 * @return  int
	 *
	 * @since   2.0.0
	 */
	public function getDir()
	{
		return $this->dir;
	}
}
