<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
namespace Sellacious\StoreTimings;

// no direct access
defined('_JEXEC') or die;

use Exception;

/**
 * Class Slots
 *
 * @package Sellacious\StoreTimings
 *
 * @since   2.0.0
 */
class Slots
{
	/**
	 * The default slots timezone, can be override in slot objects
	 *
	 * @var  string
	 *
	 * @since   2.0.0
	 */
	protected $tz;

	/**
	 * The slots instances
	 *
	 * @var  slot[]
	 *
	 * @since   2.0.0
	 */
	protected $slots = array();

	/**
	 * Slots constructor
	 *
	 * @param   string  $tz
	 *
	 * @since   2.0.0
	 */
	public function __construct($tz = 'UTC')
	{
		$this->tz = $tz;
	}

	/**
	 * Add a slot object
	 *
	 * @param   Slot  $slot
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function add(Slot $slot)
	{
		$this->slots[] = $slot;
	}

	/**
	 * Add slot using plain format
	 *
	 * @param   string  $day
	 * @param   string  $start
	 * @param   string  $end
	 * @param   string  $tz
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function addTime($day, $start, $end, $tz = null)
	{
		$this->add(new Slot($day, $start, $end, $tz ?: $this->tz));
	}

	/**
	 * Convert the slots to another timezone taking into account the day change
	 *
	 * @param   string  $tz
	 *
	 * @return  Slots
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function convert($tz)
	{
		$slots = new Slots($tz);

		foreach ($this->slots as $slot)
		{
			$values = $slot->convert($tz);

			foreach ($values as $value)
			{
				$slots->add($value);
			}
		}

		return $slots;
	}

	/**
	 * Return an array representation of the slot
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	public function toArray()
	{
		$slots = array();

		foreach ($this->slots as $slot)
		{
			$slots[] = $slot->toArray();
		}

		return $slots;
	}
}
