<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
use Joomla\Utilities\ArrayHelper;

defined('_JEXEC') or die;

/**
 * List controller class.
 *
 * @since   2.0.0
 */
class SellaciousControllerCommissions extends SellaciousControllerAdmin
{
	/**
	 * @var    string  The prefix to use with controller messages.
	 *
	 * @since   2.0.0
	 */
	protected $text_prefix = 'COM_SELLACIOUS_CATEGORIES';

	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function __construct($config = array())
	{
		parent::__construct($config);

		$this->registerTask('apply', 'save');
	}

	/**
	 * Method to save commissions
	 *
	 * @return  bool
	 *
	 * @since   2.0.0
	 */
	public function save()
	{
		$data  = $this->input->get('jform', array(), 'Array');
		$model = $this->getModel('Commissions');
		$state = $model->getState();

		$context = $state->get('filter.context');
		$type    = $state->get('filter.form_type');

		$this->setRedirect($this->getRedirectURL());

		if (!$context)
		{
			$this->setMessage(JText::_('COM_SELLACIOUS_COMMISSIONS_INVALID_CONTEXT'), 'warning');
			return false;
		}

		$id               = ArrayHelper::getValue($data, 'id');
		$sellerCommission = ArrayHelper::getValue($data, 'commission');

		if (!$id)
		{
			$this->setMessage(JText::_('COM_SELLACIOUS_COMMISSIONS_INVALID_CATEGORY'), 'warning');
			return false;
		}

		if ($type == 'com_sellacious.user' && $context == 'product')
		{
			$this->helper->seller->setCommissions($id, $sellerCommission);
		}
		elseif ($context == 'seller')
		{
			$this->helper->category->setSellerCommissionByProductCategory($id, $sellerCommission);
		}
		elseif ($context == 'product')
		{
			$this->helper->category->setSellerCommissionBySellerCategory($id, $sellerCommission);
		}

		$this->setMessage(JText::_('COM_SELLACIOUS_COMMISSIONS_SAVE_SUCCESS'));

		return true;
	}

	/**
	 * Get redirect url taking care of all modifiers
	 *
	 * @return  string
	 *
	 * @since   2.0.0
	 */
	protected function getRedirectURL()
	{
		$task     = $this->getTask();
		$model    = $this->getModel('Commissions');
		$state    = $model->getState();
		$id       = $state->get('category_id');
		$currency = $state->get('currency');
		$context  = $state->get('filter.context');
		$type     = $state->get('filter.form_type');

		$url = 'index.php?option=com_sellacious&view=commissions&id=' . $id . '&currency=' . $currency . '&filter[context]=' . $context . '&filter[form_type]=' . $type;

		if ($task == 'apply')
		{
			$url = JRoute::_($url . '&layout=apply', false);
		}
		else
		{
			$url = JRoute::_($url . '&layout=close', false);
		}

		return $url;
	}
}
