<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access.
defined('_JEXEC') or die;

/**
 * Form Field class for checkbox matrix
 *
 * @since   1.6.0
 */
class JFormFieldCheckMatrix extends JFormField
{
	/**
	 * The field type
	 *
	 * @var    string
	 *
	 * @since   1.6.0
	 */
	protected $type = 'CheckMatrix';

	/**
	 * Name of the layout being used to render the field
	 *
	 * @var    string
	 *
	 * @since   1.6.0
	 */
	protected $layout = 'sellacious.formfield.checkmatrix.default';

	protected $rows;

	protected $columns;

	/**
	 * Method to get the field options
	 *
	 * @return  string  The field option objects
	 *
	 * @since   1.6.0
	 */
	protected function getInput()
	{
		$this->loadVectors();

		$data = array(
			'field'   => $this,
			'rows'    => $this->rows,
			'columns' => $this->columns,
		);

		return JLayoutHelper::render($this->layout, $data);
	}

	/**
	 * Method to get the field options.
	 *
	 * @since   1.6.0
	 */
	protected function loadVectors()
	{
		$columns = array();
		$rows    = array();

		foreach ($this->element->xpath('row') as $option)
		{
			$value = (string) $option['value'];
			$rCols = trim((string) $option['columns']);
			$text  = trim((string) $option);
			$text  = strlen($text) ? $text : $value;
			$rCols = strlen($rCols) ? explode(',', $rCols) : null;

			$tmp = array(
				'value'    => $value,
				'text'     => JText::_($text),
				'columns'  => $rCols,
			);

			$rows[$value] = (object) $tmp;
		}

		foreach ($this->element->xpath('column') as $option)
		{
			$value = (string) $option['value'];
			$cRows = trim((string) $option['rows']);
			$text  = trim((string) $option);
			$text  = strlen($text) ? $text : $value;
			$cRows = strlen($cRows) ? explode(',', $cRows) : null;

			$tmp = array(
				'value'    => $value,
				'text'     => JText::_($text),
				'rows'     => $cRows,
			);

			$columns[$value] = (object) $tmp;
		}

		reset($rows);
		reset($columns);

		$this->rows    = $rows;
		$this->columns = $columns;
	}

	/**
	 * Method to add row vector to the matrix
	 *
	 * @param   string  $value    Name of the row
	 * @param   string  $text     Text to be shown for the row (Should be a lang key, without JText)
	 * @param   array   $columns  Limit the row to particular columns
	 *
	 * @since   2.0.0
	 */
	public function addRow($value, $text, $columns = null)
	{
		if ($value && $text && $this->element instanceof SimpleXMLElement)
		{
			$child = $this->element->addChild('row', $text);

			$child->addAttribute('value', $value);

			if ($columns)
			{
				$child->addAttribute('columns', implode(',', $columns));
			}
		}
	}

	/**
	 * Method to add column vector to the matrix
	 *
	 * @param   string  $value  Name of the row
	 * @param   string  $text   Text to be shown for the row (Should be a lang key, without JText)
	 * @param   array   $rows   Limit the row to particular rows
	 *
	 * @since   2.0.0
	 */
	public function addColumn($value, $text, $rows = null)
	{
		if ($value && $text && $this->element instanceof SimpleXMLElement)
		{
			$child = $this->element->addChild('column', $text);

			$child->addAttribute('value', $value);

			if ($rows)
			{
				$child->addAttribute('rows', implode(',', $rows));
			}
		}
	}
}
