<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// no direct access
defined('_JEXEC') or die;

JFormHelper::loadFieldClass('radio');

/**
 * Form Field class for the Joomla Platform. Provides radio button inputs as  switch
 *
 * @since  2.0.0
 */
class JFormFieldRadioSwitch extends JFormFieldRadio
{
	/**
	 * The form field type.
	 *
	 * @var    string
	 *
	 * @since  2.0.0
	 */
	protected $type = 'radioswitch';

	/**
	 * Name of the layout being used to render the field
	 *
	 * @var    string
	 *
	 * @since  2.0.0
	 */
	protected $layout = 'sellacious.form.field.radioswitch';

	protected $trueValue = '1';

	protected $falseValue = '0';

	protected $trueLabel = '';

	protected $falseLabel = '';

	/**
	 * Method to set certain otherwise inaccessible properties of the form field object.
	 *
	 * @param   string  $name   The property name for which to set the value.
	 * @param   mixed   $value  The value of the property.
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function __set($name, $value)
	{
		switch ($name)
		{
			case 'trueValue':
			case 'falseValue':
			case 'trueLabel':
			case 'falseLabel':
				$this->$name = (string) $value;
				break;

			default:
				parent::__set($name, $value);
		}
	}

	public function __get($name)
	{
		switch ($name)
		{
			case 'trueValue':
			case 'falseValue':
			case 'trueLabel':
			case 'falseLabel':
				return $this->$name;

			default:
				return parent::__get($name);
		}
	}

	/**
	 * Method to attach a JForm object to the field.
	 *
	 * @param   SimpleXMLElement  $element  The SimpleXMLElement object representing the `<field>` tag for the form field object.
	 * @param   mixed             $value    The form field value to validate.
	 * @param   string            $group    The field name group control value. This acts as as an array container for the field.
	 *                                      For example if the field has name="foo" and the group value is set to "bar" then the
	 *                                      full field name would end up being "bar[foo]".
	 *
	 * @return  boolean  True on success
	 *
	 * @since   2.0.0
	 */
	public function setup(SimpleXMLElement $element, $value, $group = null)
	{
		$setup = parent::setup($element, $value, $group);

		if ($setup)
		{
			$trueValue  = (string) $element['trueValue'];
			$falseValue = (string) $element['falseValue'];
			$trueLabel  = (string) $element['trueLabel'];
			$falseLabel = (string) $element['falseLabel'];

			$this->__set('trueValue', $trueValue === '' ? '1' : $trueValue);
			$this->__set('falseValue', $falseValue === '' ? '0' : $falseValue);
			$this->__set('trueLabel', $trueLabel ? JText::_($trueLabel) : '');
			$this->__set('falseLabel', $falseLabel ? JText::_($falseLabel) : '');
		}

		return $setup;
	}
}
