<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

defined('_JEXEC') or die;

use Sellacious\Access\AccessHelper;

/**
 * Delivery Controller
 *
 * @since  1.7.0
 */
class SellaciousdeliveryController extends SellaciousControllerBase
{
	/**
	 * Display a view.
	 *
	 * @param   boolean  $cachable   If true, the view output will be emid
	 * @param   array    $urlparams  An array of safe url parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return  JControllerLegacy  This object to support chaining.
	 *
	 * @since   1.7.0
	 */
	public function display($cachable = false, $urlparams = false)
	{
		$vName = $this->input->get('view', 'orders');

		$this->input->set('view', $vName);

		switch ($vName)
		{
			case 'slots':
				$allowed = true;
				break;
			case 'orders':
				$allowed = AccessHelper::allowSome(array('list.own', 'list'), 'order.', 'com_sellaciousdelivery');
				break;
			default:
				$allowed = null;
		}

		if (!$allowed)
		{
			$tmpl = $this->input->get('tmpl', null);

			if ($tmpl !== 'raw')
			{
				$message = $allowed === false ? JText::_('COM_SELLACIOUS_ACCESS_NOT_ALLOWED') : JText::_('COM_SELLACIOUS_PAGE_NOT_FOUND');
				$suffix  = !empty($tmpl) ? '&tmpl=' . $tmpl : '';

				$this->setMessage($message, 'error');
				$this->setRedirect(JRoute::_('index.php?option=com_sellacious' . $suffix, false));
			}

			return $this;
		}

		return parent::display($cachable, $urlparams);
	}
}
