<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */
// No direct access
use Sellacious\StoreTimings\Slots;

defined('_JEXEC') or die;

/**
 * Sellacious model.
 *
 * @since   2.0.0
 */
class SellaciousdeliveryModelSlots extends SellaciousModel
{
	/**
	 * Method to auto-populate the model state.
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	protected function populateState()
	{
		parent::populateState();

		$type       = $this->app->input->getString('type', 'delivery');
		$shipRuleId = $this->app->input->getInt('shipping_rule_id');
		$sellerUid  = $this->app->input->getInt('seller_uid');

		$this->state->set('slots.type', $type);
		$this->state->set('slots.shipping_rule_id', $shipRuleId);
		$this->state->set('slots.seller_uid', $sellerUid);
	}

	/**
	 * Method to get Slots for weekday
	 *
	 * @param   int  $weekDay
	 *
	 * @return  Slots
	 *
	 * @since  2.0.0
	 */
	public function getSlots($weekDay)
	{
		static $weekSlots;

		if (!isset($weekSlots[$weekDay]))
		{
			$type       = $this->state->get('slots.type', 'delivery');
			$sellerUid  = $this->state->get('slots.seller_uid');
			$shipRuleId = $this->state->get('slots.shipping_rule_id');
			$slots      = new Slots();

			$dispatcher = $this->helper->core->loadPlugins();
			$dispatcher->trigger('onGetTimeSlots', array('com_sellaciousdelivery.slots', &$slots, $sellerUid, $weekDay, $type, $shipRuleId));

			$weekSlots[$weekDay] = $slots;
		}

		return $weekSlots[$weekDay];
	}

	/**
	 * Method to set slot rates
	 *
	 * @param   array  $data
	 *
	 * @return  bool
	 *
	 * @since   2.0.0
	 */
	public function setSlotRates($data)
	{
		$dispatcher = $this->helper->core->loadPlugins();
		$dispatcher->trigger('onSaveSlotRates', array('com_sellaciousdelivery.slots', $data));

		return true;
	}
}
