<?php
/**
 * @version     2.0.0
 * @package     com_sellaciousreporting
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

defined('_JEXEC') or die;

use Sellacious\Access\AccessHelper;

/**
 * Reporting component helper.
 *
 * @since  1.6.0
 */
class ReportingHelper
{
	/**
	 * Method to get Current User categories
	 *
	 * @throws \Exception
	 *
	 * @return  array   user categories
	 *
	 * @since   1.6.0
	 */
	public static function getUserCategories()
	{
		$user   = JFactory::getUser();
		$helper = SellaciousHelper::getInstance();

		$userCategories = array();
		$userCategories[] = $helper->seller->getCategory($user->id);
		$userCategories[] = $helper->client->getCategory($user->id);
		$userCategories[] = $helper->staff->getCategory($user->id);
		$userCategories[] = $helper->manufacturer->getCategory($user->id);

		$userCategories = array_filter($userCategories);
		sort($userCategories);

		return $userCategories;
	}
	
	/**
	 * Method to get allowed user categories for a report permission
	 *
	 * @param   int     $reportId  Id of the report
	 * @param   string  $type      Type of permission
	 *
	 * @return  array
	 *
	 * @since   2.0.0
	 */
	public static function getAllowedUserCategories($reportId, $type = 'edit')
	{
		$db    = JFactory::getDbo();
		$query = $db->getQuery(true);

		$query->select('a.user_cat_id')
			->from($db->qn('#__sellacious_reports_permissions', 'a'))
			->where('a.report_id = ' . (int) $reportId)
			->where('a.permission_type = ' . $db->q($type));

		$db->setQuery($query);

		return $db->loadColumn();
	}

	/**
	 * Method to get report data
	 *
	 * @param   $reportId   int  The report ID
	 *
	 * @return  stdClass
	 *
	 * @throws  Exception
	 *
	 * @since   1.6.0
	 */
	public static function getReportData($reportId)
	{
		$table = SellaciousTable::getInstance('Report');
		$table->load($reportId);

		$result = (object) $table->getProperties(1);

		return $result;
	}

	/**
	 * Method to check whether user can edit or view a report
	 *
	 * @param   int     $id    Report id
	 * @param   string  $type  Type of permission
	 *
	 * @return  bool
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public static function canAccessReport($id, $type = 'edit')
	{
		if (!$id)
		{
			return true;
		}

		$user                  = JFactory::getUser();
		$report                = static::getReportData($id);
		$allowedUserCategories = static::getAllowedUserCategories($id, $type);
		$userCategories        = static::getUserCategories();
		$matched               = array_intersect($allowedUserCategories, $userCategories);

		$allow = AccessHelper::allow('report.' . $type, 'com_sellaciousreporting')
		     || $report->created_by == $user->id && AccessHelper::allow('report.edit.own', 'com_sellaciousreporting')
		     || (AccessHelper::allow('report.list.assigned', 'com_sellaciousreporting') && !empty($allowedUserCategories) && $matched);

		return $allow;
	}
}
