<?php
/**
 * @version     2.0.0
 * @package     com_sellaciousreporting
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     SPL Sellacious Private License; see http://www.sellacious.com/spl.html
 * @author      Aditya Chakraborty <info@bhartiy.com> - http://www.bhartiy.com
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;
use Sellacious\Access\AccessHelper;
use Sellacious\Toolbar\Button\StandardButton;
use Sellacious\Toolbar\ButtonGroup;
use Sellacious\Toolbar\Toolbar;
use Sellacious\Toolbar\ToolbarHelper;

/**
 * HTML View class for the Reports component
 *
 * @since  1.6.0
 */
class SellaciousreportingViewReports extends SellaciousViewList
{
	/** @var  string */
	protected $action_prefix = 'report';

	/** @var  string */
	protected $view_item = 'report';

	/** @var  string */
	protected $view_list = 'reports';

	/**
	 * Add the page title and toolbar.
	 *
	 * @since  2.0.0
	 */
	protected function addToolbar()
	{
		$state = $this->get('State');

		$this->setPageTitle();

		$toolbar = Toolbar::getInstance();

		$editable = $this->view_item && file_exists(JPATH_COMPONENT . '/views/' . $this->view_item);

		if ($editable && AccessHelper::allow($this->action_prefix . '.create', 'com_sellaciousreporting'))
		{
			$toolbar->appendButton(new StandardButton('new', 'JTOOLBAR_NEW', $this->view_item . '.add', false));
		}

		$gState = new ButtonGroup('state', 'COM_SELLACIOUS_BUTTON_GROUP_BULK_OPTIONS');
		$toolbar->appendGroup($gState);

		if (count($this->items))
		{
			if (AccessHelper::allowSome(array('edit.state', 'edit.state.own'), $this->action_prefix . '.', 'com_sellaciousreporting'))
			{
				if (!is_numeric($state->get('filter.state')) || $state->get('filter.state') != '1')
				{
					$gState->appendButton(new StandardButton('publish', 'JTOOLBAR_PUBLISH', $this->view_list . '.publish', true));
				}

				if (!is_numeric($state->get('filter.state')) || $state->get('filter.state') != '0')
				{
					$gState->appendButton(new StandardButton('unpublish', 'JTOOLBAR_UNPUBLISH', $this->view_list . '.unpublish', true));
				}

				if (!is_numeric($state->get('filter.state')) || $state->get('filter.state') != '-2')
				{
					$gState->appendButton(new StandardButton('trash', 'JTOOLBAR_TRASH', $this->view_list . '.trash', true));
				}
				// If 'edit.state' is granted, then show 'delete' only if filtered on 'trashed' items
				elseif ($state->get('filter.state') == '-2' && $this->helper->access->checkAny(array('.delete', '.delete.own'), $this->action_prefix, null, 'com_sellaciousreporting'))
				{
					ToolBarHelper::deleteList('', $this->view_list . '.delete', 'JTOOLBAR_DELETE');
				}
			}
			// We can allow direct 'delete' implicitly for his (seller) own items if so permitted.
			elseif (AccessHelper::allowSome(array('delete', 'delete.own'), $this->action_prefix . '.', 'com_sellaciousreporting'))
			{
				ToolBarHelper::trash($this->view_list . '.delete', 'JTOOLBAR_DELETE');
			}
		}

		if ($this->is_nested && AccessHelper::allow('core.admin'))
		{
			ToolBarHelper::custom($this->view_list . '.rebuild', 'refresh.png', 'refresh_f2.png', 'JTOOLBAR_REBUILD', false);
		}
	}
}
