<?php
/**
 * @version     2.0.0
 * @package     sellacious
 *
 * @copyright   Copyright (C) 2012-2020 Bhartiy Web Technologies. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Izhar Aazmi <info@bhartiy.com> - http://www.bhartiy.com
 */
// No direct access
defined('_JEXEC') or die('Restricted access');

use Joomla\Registry\Registry;
use Sellacious\Event\EventHelper;
use Sellacious\Template\AbstractTemplate;

jimport('sellacious.loader');

/**
 * Sellacious events forward plugin
 *
 * @since  2.0.0
 */
class PlgSystemSellaciousEvents extends JPlugin
{
	/**
	 * Load the language file on instantiation
	 *
	 * @var    bool
	 *
	 * @since  2.0.0
	 */
	protected $autoloadLanguage = true;

	/**
	 * Forward onAfterInitialise events
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function onAfterInitialise()
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onAfterInitialise', array());
		}
	}


	/**
	 * Forward onAfterRoute events
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function onAfterRoute()
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onAfterRoute', array());
		}
	}

	/**
	 * Forward prepareForm events
	 *
	 * @param   JForm  $form  The form to be altered
	 * @param   array  $data  The associated data for the form
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function onContentPrepareForm($form, $data)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onPrepareForm', array('form' => &$form, 'data' => &$data));
		}
	}

	/**
	 * Forwards prepareFormData events
	 *
	 * @param   string  $context  The context for the data
	 * @param   mixed   $data     An object containing the data for the form.
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function onContentPrepareData($context, $data)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onPrepareFormData', array('context' => $context, 'data' => &$data));
			$data  = $event->getArgument('data');
		}
	}

	/**
	 * Forwards contentAfterSave events
	 *
	 * @param   string  $context  The calling context
	 * @param   object  $table    A JTable object
	 * @param   bool    $isNew    If the content is just about to be created
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function onContentAfterSave($context, $table, $isNew)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onContentAfterSave', array('context' => $context, 'table' => &$table, 'isNew' => $isNew));
		}
	}

	/**
	 * Fetch the available context of email template
	 *
	 * @param   string    $context   The calling context
	 * @param   string[]  $contexts  The list of email context the should be populated
	 *
	 * @return  void
	 *
	 * @since   2.0.0
	 */
	public function onFetchEmailContext($context, array &$contexts = array())
	{
		if (class_exists('Sellacious\Event\EventHelper') && $context === 'com_sellacious.emailtemplate')
		{
			$event = EventHelper::trigger('onFetchNotificationContext', array('context' => 'com_sellacious.notification', 'contexts' => $contexts));

			$contexts = $event->getArgument('contexts');
		}
	}

	/**
	 * Forwards onLoadProductFilters events
	 *
	 * @param   string  $context  The calling context
	 * @param   array   $filters  List of filters
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function onLoadProductFilters($context, &$filters)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onLoadProductFilters', array('context' => $context, 'filters' => &$filters));
		}
	}

	/**
	 * Forwards onProcessListQuery events
	 *
	 * @param   string          $context  The calling context
	 * @param   JDatabaseQuery  $query    The database query to process
	 * @param   JObject         $state    The model state object
	 *
	 * @return  void
	 *
	 * @throws  Exception
	 *
	 * @since   2.0.0
	 */
	public function onProcessListQuery($context, $query, $state)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onProcessListQuery', array('context' => $context, 'query' => $query, 'state' => $state));
		}
	}

	/**
	 * Forwards onLoadTemplateVariables events
	 *
	 * @param  AbstractTemplate  $template
	 * @param  string            $context
	 *
	 * @since  2.0.0
	 */
	public function onLoadTemplateVariables($template, $context)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			EventHelper::trigger('onLoadTemplateVariables', array('template' => $template, 'context' => $context));
		}
	}

	/**
	 * Forwards onParseTemplate event
	 *
	 * @param   string    $context      The context for the data
	 * @param   Registry  $data         The data object
	 * @param   array     $replacements Array of replacements by code
	 *
	 * @since   2.0.0
	 */
	public function onParseTemplate($context, $data, &$replacements)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onParseTemplate', array('context' => $context, 'data' => $data, 'replacements' => &$replacements));

			$replacements = $event->getArgument('replacements');
		}
	}

	/**
	 * Forwards onRenderFormValues event
	 *
	 * @param  string    $context  The calling context
	 * @param  Registry  $data     The data object
	 * @param  array     $values   Array of Form values
	 *
	 * @since  2.0.0
	 */
	public function onRenderFormValues($context, $data, &$values)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onRenderFormValues', array('context' => $context, 'data' => $data, 'values' => &$values));

			$values = $event->getArgument('values');
		}
	}

	/**
	 * Forwards onProcessProduct event
	 *
	 * @param   string     $context  The calling context
	 * @param   \stdClass  $item     The product object in question
	 *
	 * @since   2.0.0
	 */
	public function onProcessProduct($context, $item)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onProcessProduct', array('context' => $context, 'item' => $item));

			$item = $event->getArgument('item');
		}
	}

	/**
	 * Forwards OnParseViewTemplate event
	 *
	 * @param   $context  string     The calling context
	 * @param   $data    \JRegistry  The data object
	 * @param   $html     string     The html layout
	 * @param   $options  array      Extra Options
	 *
	 * @since   2.0.0
	 */
	public function onParseViewTemplate($context, $data, &$html, $options = array())
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('OnParseViewTemplate', array('context' => $context, 'data' => $data, 'html' => &$html, 'options' => $options));

			$html = $event->getArgument('html');
		}
	}

	/**
	 * Forwards onTemplatePreview event
	 *
	 * @param  string  $context          The calling context
	 * @param  string  $templateContext  The template context
	 * @param  string  $body             The html string which needs to be replaced
	 *
	 * @throws  \Exception
	 *
	 * @since   2.0.0
	 */
	public function onTemplatePreview($context, $templateContext, &$body)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onTemplatePreview', array('context' => $context, 'templateContext' => $templateContext, 'body' => &$body));

			$body = $event->getArgument('body');
		}
	}

	/**
	 * Forwards onParseProductRow event
	 *
	 * @param   string     $context       The calling context
	 * @param   \stdClass  $product       The product object
	 * @param   array      $replacements  Array of short code replacements
	 *
	 * @since   2.0.0
	 */
	public function onParseProductRow($context, $product, &$replacements)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onParseProductRow', array('context' => $context, 'product' => $product, 'replacements' => &$replacements));

			$replacements = $event->getArgument('replacements');
		}
	}

	/**
	 * Forwards onBeforeDisplayView events
	 *
	 * @param  string          $context
	 * @param  SellaciousView  $view
	 *
	 * @since  2.0.0
	 */
	public function onBeforeDisplayView($context, &$view)
	{
		if (class_exists('Sellacious\Event\EventHelper'))
		{
			$event = EventHelper::trigger('onBeforeDisplayView', array('context' => $context, 'view' => $view));
			$view  = $event->getArgument('view');
		}
	}
}
